@@ -11,7 +11,7 @@ import math
 import time
 from numba import cuda
 import numba
-#import pyculib
+import pyculib
 
 from numba import njit, prange
 import cgwpy.tools as tool
@@ -419,7 +419,7 @@ def signal_correction_algebric(signal_data,S_matrix, R_matrix, T_matrix,  mesh_p
     #define parameters of the observation
     start      = astropy.time.Time(signal_data.times[0], format='gps') # 1238166018, 1253977218
     stop       = astropy.time.Time(signal_data.times[-1],format='gps')
-    f_sampling = h_data.sample_rate.value
+    f_sampling = signal_data.sample_rate.value
 
 
 
@@ -659,7 +659,7 @@ def R_matrix_parrallel(t1,t2,f_sampling):
 
 
     earth         = solar_system_ephemeris.bodies[3]
-    nb_vector     = (t2-t1)*f_sampling
+    nb_vector     = int((t2-t1)*f_sampling)+1
     number_of_cpu = joblib.cpu_count()
 
     delayed_funcs = [delayed(compute_vect)(t1, i ,f_sampling) for i in range(nb_vector)]
